@@ -527,7 +527,7 @@ install_type() {
     alpine)
         echo "apk"
         ;;
-    arch|manjaro)
+    arch|manjaro|steamos)
         #echo "arch" # TODO: fix AUR install
         echo "bin"
         ;;
@@ -584,6 +584,9 @@ install_type() {
     ubios)
         echo "ubios"
         ;;
+    gentoo)
+        echo "bin"
+        ;;
     void)
         # TODO: pkg for xbps
         echo "bin"
@@ -890,7 +893,7 @@ detect_os() {
                 fi
                 echo "$dist"; return 0
                 ;;
-            debian|ubuntu|elementary|raspbian|centos|fedora|rhel|arch|manjaro|openwrt|clear-linux-os|linuxmint|opensuse-tumbleweed|opensuse-leap|opensuse|solus|pop|neon|overthebox|sparky|vyos|void|alpine|Deepin)
+            debian|ubuntu|elementary|raspbian|centos|fedora|rhel|arch|manjaro|openwrt|clear-linux-os|linuxmint|opensuse-tumbleweed|opensuse-leap|opensuse|solus|pop|neon|overthebox|sparky|vyos|void|alpine|Deepin|gentoo|steamos)
                 echo "$dist"; return 0
                 ;;
             esac
@@ -953,7 +956,7 @@ guess_host_type() {
     pfsense|opnsense|openwrt|asuswrt-merlin|edgeos|ddwrt|synology|overthebox|ubios)
         echo "router"
         ;;
-    darwin)
+    darwin|steamos)
         echo "workstation"
         ;;
     *)
@@ -988,7 +991,7 @@ silent_exec() {
 
 bin_location() {
     case $OS in
-    centos|fedora|rhel|debian|ubuntu|elementary|raspbian|arch|manjaro|clear-linux-os|linuxmint|opensuse-tumbleweed|opensuse-leap|opensuse|solus|pop|neon|sparky|vyos|void|alpine|Deepin)
+    centos|fedora|rhel|debian|ubuntu|elementary|raspbian|arch|manjaro|clear-linux-os|linuxmint|opensuse-tumbleweed|opensuse-leap|opensuse|solus|pop|neon|sparky|vyos|void|alpine|Deepin|gentoo)
         echo "/usr/bin/nextdns"
         ;;
     openwrt|overthebox)
@@ -1012,6 +1015,9 @@ bin_location() {
     ubios)
         echo "/data/nextdns"
         ;;
+    steamos)
+        echo "$HOME/.local/bin/nextdns"
+        ;;
     *)
         log_error "Unknown bin location for $OS"
         ;;
